/**
  @author Ben Lau <xbenlau@gmail.com>
 */
#ifndef MAEMO5COLORDIALOG_H
#define MAEMO5COLORDIALOG_H

#include <QDialog>

namespace Ui {
    class Maemo5ColorDialog;
}

class Maemo5ColorDialog : public QDialog
{
    Q_OBJECT

public:
    explicit Maemo5ColorDialog(QWidget *parent = 0);
    ~Maemo5ColorDialog();

    void setCurrentColor(QColor val);
    QColor selectedColor();

protected:
    void changeEvent(QEvent *e);

private slots:
    void on_randomButton_clicked();
    void on_doneButton_clicked();
    void updateColor();
private:
    QColor m_color;
    Ui::Maemo5ColorDialog *ui;
};

#endif // MAEMO5COLORDIALOG_H
